@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.60';
+  $Devel::PatchPerl::VERSION = '0.64';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -12,6 +12,7 @@ use File::Spec;
 use IO::File;
 use IPC::Cmd qw[can_run run];
 use Devel::PatchPerl::Hints qw[hint_file];
+use Module::Pluggable search_path => ['Devel::PatchPerl::Plugin'];
 use vars qw[@ISA @EXPORT_OK];
 
 @ISA       = qw(Exporter);
@@ -164,9 +165,41 @@ sub patch_source {
          $sub->(@args);
        }
     }
+    _process_plugin( version => $vers, source => $source, patchexe => $patch_exe );
   }
 }
 
+sub _process_plugin {
+  my %args = @_;
+  return unless my $possible = $ENV{PERL5_PATCHPERL_PLUGIN};
+  my ($plugin) = grep { $possible eq $_ or /\Q$possible\E$/ } __PACKAGE__->plugins;
+  unless ( $plugin ) {
+    warn "# You specified a plugin '", $ENV{PERL5_PATCHPERL_PLUGIN},
+         "' that isn't installed, just thought you might be interested.\n";
+    return;
+  }
+  {
+    local $@;
+    eval "require $plugin";
+    if ($@) {
+      die "# I tried to load '", $ENV{PERL5_PATCHPERL_PLUGIN},
+          "' but it didn't work out. Here is what happened '$@'\n";
+    }
+  }
+  {
+    local $@;
+    eval {
+      $plugin->patchperl(
+        %args,
+      );
+    };
+    if ($@) {
+      warn "# Warnings from the plugin: '$@'\n";
+    }
+  }
+  return 1;
+}
+
 sub _is
 {
   my($s1, $s2) = @_;
@@ -1756,7 +1789,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.60
+version 0.64
 
 =head1 SYNOPSIS
 
@@ -1792,17 +1825,23 @@ current working directory.
 
 =back
 
+=head1 PLUGIN SYSTEM
+
+See L<Devel::PatchPerl::Plugin> for details of Devel::PatchPerl's plugin system.
+
 =head1 SEE ALSO
 
 L<Devel::PPPort>
 
+L<Devel::PatchPerl::Plugin>
+
 =head1 AUTHOR
 
 Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chris Williams and Marcus Holland-Moritz.
+This software is copyright (c) 2012 by Chris Williams and Marcus Holland-Moritz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
